twine upload -u shivajiwankhede -p Renuka@9850 --repository-url https://test.pypi.org/legacy/ dist/*

twine upload -u shivajiwankhede -p Renuka@9850 --repository-url https://upload.pypi.org/legacy/ dist/* -p pypi-AgEIcHlwaS5vcmcCJDM0MzBkOGQ3LTZlYWYtNGIyNC04ODEzLWRjY2UyM2QzMjA2YgACKlszLCI4YjkzY2RmNy05YWRjLTQwYmYtYWE2OC04NmRjZDY5N2FiNDYiXQAABiBi6voRO4ad9KEu4SsEZ5me18GVdxFk1UDMWXfjwagMpA
